@@ -1,5 +1,5 @@
 #
-# Copyright © 2012 - 2021 Michal Čihař <michal@cihar.com>
+# Copyright © 2012–2022 Michal Čihař <michal@cihar.com>
 #
 # This file is part of Weblate translation-finder
 # <https://github.com/WeblateOrg/translation-finder>
@@ -51,9 +51,11 @@ LANGUAGES_BLACKLIST = {
     "fur",
     "nor",
     "bar",
+    "bug",
     "cat",
     "cop",
     "cos",
+    "dry",
     "hit",
     "new",
     "sin",
