@@ -144,6 +144,12 @@ class OSXDiscovery(EncodingDiscovery):
 
             yield {"filemask": "/".join(mask), "template": path.as_posix()}
 
+        for path in self.finder.filter_files(r"base\.strings"):
+            mask = list(path.parts)
+            mask[-1] = "*.strings"
+
+            yield {"filemask": "/".join(mask), "template": path.as_posix()}
+
 
 @register_discovery
 class StringsdictDiscovery(BaseDiscovery):
@@ -205,6 +211,15 @@ class RESXDiscovery(BaseDiscovery):
         yield from super().get_masks(eager=eager)
 
 
+@register_discovery
+class ResourceDictionaryDiscovery(BaseDiscovery):
+    """ResourceDictionary files discovery."""
+
+    file_format = "resourcedictionary"
+    mask = "*.xaml"
+    new_base_mask = "*.xaml"
+
+
 @register_discovery
 class AppStoreDiscovery(BaseDiscovery):
     """App store metadata."""
