@@ -37,6 +37,7 @@ from .discovery.files import (
     PHPDiscovery,
     QtDiscovery,
     RCDiscovery,
+    ResourceDictionaryDiscovery,
     RESXDiscovery,
     StringsdictDiscovery,
     TOMLDiscovery,
@@ -608,6 +609,32 @@ class OSXTest(DiscoveryTestCase):
             ],
         )
 
+    def test_pappl(self):
+        discovery = OSXDiscovery(
+            self.get_finder(
+                [
+                    "pappl/strings/de.strings",
+                    "pappl/strings/en.strings",
+                    "pappl/strings/ja.strings",
+                    "pappl/strings/base.strings",
+                    "pappl/strings/es.strings",
+                    "pappl/strings/fr.strings",
+                    "pappl/strings/it.strings",
+                    "pappl/strings/ipp.strings",
+                ]
+            )
+        )
+        self.assert_discovery(
+            discovery.discover(),
+            [
+                {
+                    "filemask": "pappl/strings/*.strings",
+                    "file_format": "strings-utf8",
+                    "template": "pappl/strings/base.strings",
+                },
+            ],
+        )
+
 
 class StringsdictTest(DiscoveryTestCase):
     def test_basic(self):
@@ -749,6 +776,33 @@ class RESXTest(DiscoveryTestCase):
         )
 
 
+class ResourceDictionaryTest(DiscoveryTestCase):
+    def test_basic(self):
+        discovery = ResourceDictionaryDiscovery(
+            self.get_finder(
+                [
+                    "Languages/de.xaml",
+                    "Languages/en.xaml",
+                    "Languages/pl.xaml",
+                    "Languages/sk.xaml",
+                    "Languages/tr.xaml",
+                    "Languages/zh-cn.xaml",
+                    "Languages/zh-tw.xaml",
+                ]
+            )
+        )
+        self.assert_discovery(
+            discovery.discover(),
+            [
+                {
+                    "filemask": "Languages/*.xaml",
+                    "file_format": "resourcedictionary",
+                    "template": "Languages/en.xaml",
+                },
+            ],
+        )
+
+
 class XliffTest(DiscoveryTestCase):
     def test_basic(self):
         discovery = XliffDiscovery(
